@@ -4,7 +4,7 @@ import psycopg2 as db2
 from indexed_search import DB
 
 CLUSTER_NAME = "base"
-DATA_DIR = "/scratch2/postgres/data/%s" % CLUSTER_NAME
+DATA_DIR = "/tmp/pytables-data/postgres/%s" % CLUSTER_NAME
 # DATA_DIR = "/var/lib/pgsql/data/%s" % CLUSTER_NAME
 DSN = "dbname=%s port=%s"
 CREATE_DB = "createdb %s"
